==> pierogi_1.1.27.tar.gz: pierogi-1.1.27/keysets/orion.h <==
//
// orion.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef ORION_H
#define ORION_H

#include "pirkeysetmetadata.h"

class QObject;

class OrionTV1: public PIRKeysetMetaData
{
public:
  OrionTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionTV2: public PIRKeysetMetaData
{
public:
  OrionTV2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionTV3: public PIRKeysetMetaData
{
public:
  OrionTV3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionVCR1: public PIRKeysetMetaData
{
public:
  OrionVCR1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionVCR2: public PIRKeysetMetaData
{
public:
  OrionVCR2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionDVD1: public PIRKeysetMetaData
{
public:
  OrionDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // ORION_H

==> pierogi_1.1.43.tar.gz: pierogi-1.1.43/keysets/orion.h <==
//
// orion.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef ORION_H
#define ORION_H

#include "pirkeysetmetadata.h"

class QObject;
class QComboBox;

class OrionTV1: public PIRKeysetMetaData
{
public:
  OrionTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class OrionTV2: public PIRKeysetMetaData
{
public:
  OrionTV2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionTV3: public PIRKeysetMetaData
{
public:
  OrionTV3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class OrionVCR1: public PIRKeysetMetaData
{
public:
  OrionVCR1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionVCR2: public PIRKeysetMetaData
{
public:
  OrionVCR2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class OrionDVD1: public PIRKeysetMetaData
{
public:
  OrionDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // ORION_H
